@@ -2,36 +2,26 @@
 
 import io
 import pickle
-import threading
 import subprocess
 from subprocess import STDOUT
 from uuid import UUID
 
-import pkg_resources
-from bthci import ADDR_TYPE_PUBLIC, ADDR_TYPE_RANDOM
-from xpycommon.ui import green, blue, yellow, red
+from xpycommon.ui import green, blue, yellow, red, INDENT
 from xpycommon.log import Logger
+
+import pkg_resources
 from halo import Halo
-
-import dbus
-import dbus.service
-import dbus.mainloop.glib
-from dbus import SystemBus, ObjectPath
-
+from bthci import ADDR_TYPE_PUBLIC
 from btgatt import Service, CharactValueDeclar, ServiceUuids, GattAttrTypes, bt_base_uuid, \
     GattClient, ReadCharactValueError, ReadCharactDescriptorError, CharactProperties
 
-from ..common import BLUEZ_NAME, mainloop
-from ..ui import INDENT, LOG_LEVEL
 from .. import BlueScanner, ScanResult
-from .agent import Agent
-from . import LE_DEVS_SCAN_RESULT_CACHE
-from .le_scan import LeScanner
+from .ui import LOG_LEVEL
+from .gatt_scan_bt_agent import GattScanBtAgent
+
 
 logger = Logger(__name__, LOG_LEVEL)
 
-IFACE_AGENT_MGR_1 = 'org.bluez.AgentManager1'
-
 service_uuid_file = pkg_resources.resource_stream(__name__, "../res/gatt-service-uuid.txt")
 service_uuid_file = io.TextIOWrapper(service_uuid_file)
 
@@ -75,6 +65,7 @@ for line in descriptor_uuid_file:
         'Specification': items[2]
     }
     
+
 def full_uuid_str_to_16_int(uuid: str):
     """return 16-bit int or original uuid """
     if uuid.startswith("0000") and uuid.endswith(BT_BASE_UUID_SUFFIX):
@@ -82,12 +73,6 @@ def full_uuid_str_to_16_int(uuid: str):
     return uuid
 
 
-class BluingAgent(Agent):
-    def __init__(self, bus: SystemBus, idx: int, ioc: str = 'NoInputNoOutput') -> None:
-        super().__init__(bus, idx)
-        self.io_capability = ioc
-
-
 def attr_permissions2str(permissions: dict):
     permi_str = ''
     
@@ -199,10 +184,10 @@ class GattScanResult(ScanResult):
             print(blue("Service"), "(0x{:04x} - 0x{:04x}, {} characteristics)".format(
                 service.start_handle, service.end_handle, len(service.get_characts())))
             print(INDENT + blue("Declaration"))
-            print(INDENT + "Handle: 0x{:04x}".format(service.start_handle))
-            print(INDENT + "Type:   {:04X} ({})".format(service.declar.type.int16, service.declar.type.name))
-            print(INDENT + "Value:  {} ({})".format(green(uuid_str_for_show), service_name))
-            print(INDENT + "Permissions:", service.declar.permissions_desc)
+            print(INDENT*2 + "Handle: 0x{:04x}".format(service.start_handle))
+            print(INDENT*2 + "Type:   {:04X} ({})".format(service.declar.type.int16, service.declar.type.name))
+            print(INDENT*2 + "Value:  {} ({})".format(green(uuid_str_for_show), service_name))
+            print(INDENT*2 + "Permissions:", service.declar.permissions_desc)
             print() # An empty line before Characteristic Group
             
             # Prints each Gharacteristic group
@@ -228,13 +213,13 @@ class GattScanResult(ScanResult):
                     
                 print(INDENT + yellow("Characteristic"), '({} descriptors)'.format(len(charact.descriptors)))
                 print(INDENT*2 + yellow("Declaration"))
-                print(INDENT*2 + "Handle: 0x{:04x}".format(charact.declar.handle))
-                print(INDENT*2 + "Type:   {:04X} ({})".format(charact.declar.type.int16, charact.declar.type.name))
-                print(INDENT*2 + "Value:")
-                print(INDENT*3 + "Properties: {}".format(green(', '.join(charact.declar.get_property_names()))))
-                print(INDENT*3 + "Handle:    ", green("0x{:04x}".format(charact.declar.value.handle)))
-                print(INDENT*3 + "UUID:       {} ({})".format(green(uuid_str_for_show), charact_name))
-                print(INDENT*2 + "Permissions: {}\n".format(charact.declar.permissions_desc))
+                print(INDENT*3 + "Handle: 0x{:04x}".format(charact.declar.handle))
+                print(INDENT*3 + "Type:   {:04X} ({})".format(charact.declar.type.int16, charact.declar.type.name))
+                print(INDENT*3 + "Value:")
+                print(INDENT*4 + "Properties: {}".format(green(', '.join(charact.declar.get_property_names()))))
+                print(INDENT*4 + "Handle:    ", green("0x{:04x}".format(charact.declar.value.handle)))
+                print(INDENT*4 + "UUID:       {} ({})".format(green(uuid_str_for_show), charact_name))
+                print(INDENT*3 + "Permissions: {}\n".format(charact.declar.permissions_desc))
 
                 if charact.value_declar is not None:
                     try:
@@ -252,11 +237,11 @@ class GattScanResult(ScanResult):
                     else:
                         value_print = green(str(charact.value_declar.value))
                     
-                    print(INDENT*2 + yellow("Value declaration"))
-                    print(INDENT*2 + "Handle: 0x{:04x}".format(charact.value_declar.handle))
-                    print(INDENT*2 + "Type:   {} ({})".format(type_str_for_show, value_declar_name))
-                    print(INDENT*2 + "Value:  {}".format(value_print))
-                    print(INDENT*2 + "Permissions: {}\n".format(charact.value_declar.permissions_desc))
+                    print(INDENT*2 + yellow("Value"))
+                    print(INDENT*3 + "Handle: 0x{:04x}".format(charact.value_declar.handle))
+                    print(INDENT*3 + "Type:   {} ({})".format(type_str_for_show, value_declar_name))
+                    print(INDENT*3 + "Value:  {}".format(value_print))
+                    print(INDENT*3 + "Permissions: {}\n".format(charact.value_declar.permissions_desc))
                 
                 # Prints each Characteristic Descriptor
                 for descriptor in charact.get_descriptors():
@@ -274,11 +259,11 @@ class GattScanResult(ScanResult):
                             value_print = green(str(descriptor.value))
                               
                     print(INDENT*2 + yellow("Descriptor"))
-                    print(INDENT*2 + "Handle: {}".format(green('0x{:04x}'.format(descriptor.handle))))
-                    print(INDENT*2 + "Type:   {} ({})".format(green("{:04X}".format(descriptor.type.int16)), yellow(descriptor.type.name)))
-                    print(INDENT*2 + "Value: ", value_print)
-                    print(INDENT*2 + "Permissions: {}\n".format(descriptor.permissions_desc))
-                    
+                    print(INDENT*3 + "Handle: {}".format(green('0x{:04x}'.format(descriptor.handle))))
+                    print(INDENT*3 + "Type:   {} ({})".format(green("{:04X}".format(descriptor.type.int16)), yellow(descriptor.type.name)))
+                    print(INDENT*3 + "Value: ", value_print)
+                    print(INDENT*3 + "Permissions: {}\n".format(descriptor.permissions_desc))
+
     def to_dict(self) -> dict:
         j = {
             "Addr": self.addr,
@@ -294,48 +279,19 @@ class GattScanResult(ScanResult):
 
 class GattScanner(BlueScanner):
     """"""
-    def __init__(self, iface: str = 'hci0', ioc: str = 'NoInputNoOutput'):
+    def __init__(self, iface: str = 'hci0', io_cap: str = 'NoInputNoOutput'):
         super().__init__(iface=iface)
         
         self.result = GattScanResult()
         self.gatt_client = None
         self.spinner = Halo(placement='right')
-        
-        dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
-        sys_bus = SystemBus()
-        
-        self.agent_registered = False
-        
-        def register_agent_callback():
-            logger.debug('Agent object registered\n'
-                        "IO capability: {}".format(self.bluing_agent.io_capability))
-            self.agent_registered = True
-        def register_agent_error_callback(error):
-            logger.error("Failed to register agent object.\n" +
-                         "{}\n".format(error) + 
-                         "IO capability: {}".format(self.bluing_agent.io_capability))
-            self.agent_registered = False
-        self.bluing_agent = BluingAgent(sys_bus, 0, ioc)
-        self.agent_mgr_1_iface = dbus.Interface(
-            sys_bus.get_object(BLUEZ_NAME, '/org/bluez'), IFACE_AGENT_MGR_1)
-        self.agent_mgr_1_iface.RegisterAgent(
-            ObjectPath(self.bluing_agent.path), 
-            self.bluing_agent.io_capability,
-            reply_handler=register_agent_callback,
-            error_handler=register_agent_error_callback)
-        
+        self.bt_agent = GattScanBtAgent(io_cap)
+        self.bt_agent.register()
+
     def scan(self, addr: str, addr_type: int = ADDR_TYPE_PUBLIC) -> GattScanResult:
         logger.debug("Entered scan()")
-        
+
         try:
-            def run_mainloop():
-                # logger.info('mainloop run\n'
-                            # "mainloop: {}".format(mainloop))
-                mainloop.run()
-                # logger.info('mainloop stop')
-            mainloop_thread = threading.Thread(target=run_mainloop, args=[])
-            mainloop_thread.start()
-            
             self.result.addr = addr.upper()
             self.result.addr_type = addr_type
                     
@@ -381,11 +337,16 @@ class GattScanner(BlueScanner):
                     logger.debug("characts: {}".format(characts))
                 
                     for charact in characts:
-                        logger.debug("Characteristics\n" +
-                                    "Handle:       0x{:04x}\n".format(charact.declar.handle) +
-                                    "Properties:   0x{:02X}\n".format(charact.declar.value.properties) +
-                                    "Value handle: 0x{:04x}\n".format(charact.declar.value.handle) +
-                                    "UUID:         {}".format(charact.declar.value.uuid))
+                        logger.debug("Found characteristic declaration\n"
+                                     "    Handle: 0x{:04x}\n"
+                                     "    Type:   {}\n"
+                                     "    Value:\n"
+                                     "        Properties: 0x{:02X} - {}\n"
+                                     "        Handle:     0x{:04x}\n"
+                                     "        UUID:       {}".format(
+                                         charact.declar.handle, charact.declar.type, 
+                                         charact.declar.value.properties, charact.declar.get_property_names(), 
+                                         charact.declar.value.handle, charact.declar.value.uuid))
                         service.add_charact(charact)
                 except TimeoutError as e:
                     # When discovering all characteristics fo a service encounters a timeout,
@@ -538,13 +499,8 @@ class GattScanner(BlueScanner):
             if self.gatt_client is not None:
                 self.gatt_client.close()
             
-            if self.agent_registered:
-                self.agent_mgr_1_iface.UnregisterAgent(
-                    ObjectPath(self.bluing_agent.path))
-                logger.debug("Unregistered agent object")
-                
-                mainloop.quit()
-                self.agent_registered = False
+            if self.bt_agent.registered:
+                self.bt_agent.unregister()
             try:
                 # Reset and clean bluetooth service
                 output = subprocess.check_output(' '.join(['bluetoothctl', 'untrust', addr]), 
