@@ -1,13 +1,11 @@
 #!/usr/bin/env python
 
-PKG_NAME = 'uninstall'
-
-
 from xpycommon.log import INFO, DEBUG
 
-from .. import LOG_LEVEL as PARENT_LOG_LEVEL
+from .. import PKG_NAME as PARNET_PKG_NAME, LOG_LEVEL as PARENT_LOG_LEVEL
 
 
+PKG_NAME = '.'.join([PARNET_PKG_NAME, 'uninstall'])
 LOG_LEVEL = PARENT_LOG_LEVEL
 
 
