@@ -21,5 +21,5 @@ def main(argv: list[str] = sys.argv):
     try:
         BluingPluginManager.uninstall(args['NAME'])
     except Exception as e:
-        logger.error("{}: {}".format(e.__class__.__name__, e))
+        logger.error("{}: \"{}\"".format(e.__class__.__name__, e))
         sys.exit(1)
